@@ -1,13 +1,11 @@
-///////////////////////////////////////////////////////////////////////////////
-// Name:        wxsqlite3def.h
-// Purpose:     wxWidgets wrapper around the SQLite3 embedded database library.
-// Author:      Ulrich Telle
-// Created:     2005-07-14
-// Changes:     (see version history below, and accompanying readme file)
-//
-// Copyright:   (c) Ulrich Telle
-// Licence:     wxWindows licence
-///////////////////////////////////////////////////////////////////////////////
+/*
+** Name:        wxsqlite3def.h
+** Purpose:     wxWidgets wrapper around the SQLite3 embedded database library.
+** Author:      Ulrich Telle
+** Created:     2005-07-14
+** Copyright:   (c) 2005-2018 Ulrich Telle
+** License:     LGPL-3.0+ WITH WxWindows-exception-3.1
+*/
 
 /// \file wxsqlite3def.h Compile time switches for the wxSQLite3 class
 
@@ -46,6 +44,77 @@
 
 <dl>
 
+<dt><b>4.0.3</b> - <i>April 2018</i></dt>
+<dd>
+Adjusted encryption extension to better support the SQLite backup API<br>
+
+</dd>
+<dt><b>4.0.2</b> - <i>April 2018</i></dt>
+<dd>
+Upgrade to SQLite version 3.23.1<br>
+
+</dd>
+<dt><b>4.0.1</b> - <i>April 2018</i></dt>
+<dd>
+Fixed a bug in the rekeying function of the encryption extension<br>
+
+</dd>
+<dt><b>4.0.0</b> - <i>April 2018</i></dt>
+<dd>
+Introduced multi-cipher support at runtime<br>
+Added methods for attaching/detaching databases<br>
+Cleaned up code using statement buffers<br>
+Improved constness of methods<br>
+Upgrade to SQLite version 3.23.0<br>
+
+</dd>
+<dt><b>3.5.9</b> - <i>January 2018</i></dt>
+<dd>
+Upgrade to SQLite version 3.22.0<br>
+
+</dd>
+<dt><b>3.5.8</b> - <i>November 2017</i></dt>
+<dd>
+Upgrade to SQLite version 3.21.0<br>
+
+</dd>
+<dt><b>3.5.7</b> - <i>September 2017</i></dt>
+<dd>
+Upgrade to SQLite version 3.20.1<br>
+
+</dd>
+<dt><b>3.5.6</b> - <i>August 2017</i></dt>
+<dd>
+Upgrade to SQLite version 3.20.0<br>
+Added support for persistent prepared statements<br>
+Added support for binding pointers (new SQLite pointer-binding interface)<br>
+Added several SQLite extensions (csv, sha3, carray, fileio, series) for the included SQLite library<br>
+Modified build files to expose the parameter SQLITE_MAX_ATTACHED to allow easier adjustment of the maximum number of attached databases<br>
+
+</dd>
+<dt><b>3.5.5</b> - <i>June 2017</i></dt>
+<dd>
+Upgrade to SQLite version 3.19.3<br>
+
+</dd>
+<dt><b>3.5.4</b> - <i>June 2017</i></dt>
+<dd>
+Upgrade to SQLite version 3.19.2<br>
+
+</dd>
+<dt><b>3.5.3</b> - <i>March 2017</i></dt>
+<dd>
+Upgrade to SQLite version 3.18.0<br>
+Minor modification to wxsqlite3.pc.in to fix issue with pkgconfig tool<br>
+
+</dd>
+<dt><b>3.5.2</b> - <i>March 2017</i></dt>
+<dd>
+Upgrade to SQLite version 3.17.0<br>
+Fixed minor issue in SQLite encryption extension related to symbol SQLITE_DEBUG<br>
+Modified build system for GNU make (support monolithic wxWidgets build)<br>
+
+</dd>
 <dt><b>3.5.1</b> - <i>February 2017</i></dt>
 <dd>
 Added version information as Windows resource for DLL builds on Windows<br>
@@ -181,11 +250,11 @@ and for wxSQLite3 (experimental)<br>
 </dd>
 <dt><b>2.1.3</b> - <i>August 2011</i></dt>
 <dd>
-Corrected default behaviour for attached databases in case of
+Corrected default behavior for attached databases in case of
 an encrypted main database. (Now the attached database uses the same
 encryption key as the main database if no explicit key is given.
 Previously the attached database remained unencrypted.)<br>
-Added an optional progress callback for metheods Backup and Restore<br>
+Added an optional progress callback for methods Backup and Restore<br>
 Added method SetBackupRestorePageCount to set the number of pages
 to be copied in one cycle of the backup/restore process<br>
 
@@ -247,7 +316,7 @@ Added mathod FormatV to class wxSQLite3StatementBuffer<br>
 <dt><b>1.9.8</b> - <i>February 2010</i></dt>
 <dd>
 Upgrade to SQLite version 3.6.22<br>
-Fixed a bug when compiling without precompiled header support
+Fixed a bug when compiling without pre-compiled header support
 (by including wx/arrstr.h)<br>
 
 </dd>
@@ -316,7 +385,7 @@ Added static methods to initialize and shutdown the SQLite library.<br>
 Changed build system to support static library build against shared
 wxWidgets build on Linux.<br>
 Changed behaviour of wxSQLite3Database::Close method to finalize
-all unfinalized prepared statements.
+all not-finalized prepared statements.
 
 </dd>
 <dt><b>1.8.5</b> - <i>June 2008</i></dt>
@@ -477,7 +546,7 @@ First public release
 
 \author Ulrich Telle (ulrich DOT telle AT gmx DOT de)
 
-\section ackn Acknowledgements
+\section ackn Acknowledgments
 
 Kudos to <b>Fred Cailleau-Lepetit</b> for developing <b>wxSQLite+</b> as a sample demonstrating
 the wxWidgets components <b>wxAUI</b> and <b>wxSQLite3</b> and for allowing it to be included
